<?php
namespace NicolasBejean\CategoryWidget\Model\CategoryWidget;

use \NicolasBejean\CategoryWidget\Model\CategoryWidget;
use \NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget\Collection;
use \NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget\CollectionFactory;
use \Magento\Framework\App\Request\DataPersistorInterface;
use \Magento\Ui\DataProvider\AbstractDataProvider;

/**
 * Class DataProvider
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Model\CategoryWidget
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class DataProvider extends AbstractDataProvider
{
    /**
     * @var Collection
     */
    protected $collection;

    /**
     * @var DataPersistorInterface
     */
    protected $dataPersistor;

    /**
     * @var array
     */
    protected $loadedData;

    /**
     * Constructor
     *
     * @param string                    $name
     * @param string                    $primaryFieldName
     * @param string                    $requestFieldName
     * @param CollectionFactory         $categoryWidgetCollectionFactory
     * @param DataPersistorInterface    $dataPersistor
     * @param array                     $meta
     * @param array                     $data
     */
    public function __construct(
        string                          $name,
        string                          $primaryFieldName,
        string                          $requestFieldName,
        CollectionFactory               $categoryWidgetCollectionFactory,
        DataPersistorInterface          $dataPersistor,
        array $meta                     = [],
        array $data                     = []
    ) {
        $this->collection               = $categoryWidgetCollectionFactory->create();
        $this->dataPersistor            = $dataPersistor;

        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
    }

    /**
     * Get data
     *
     * @return array
     */
    public function getData()
    {
        if (isset($this->loadedData)) {
            return $this->loadedData;
        }
        $items = $this->collection->getItems();
        /** @var CategoryWidget $categoryWidget */
        foreach ($items as $categoryWidget) {
            $this->loadedData[$categoryWidget->getId()] = $categoryWidget->getData();
            if ($categoryWidget->getIdentifier()) {
                $m['identifier'] = $categoryWidget->getIdentifier();
                $fullData = $this->loadedData;
                $this->loadedData[$categoryWidget->getId()] = array_merge($fullData[$categoryWidget->getId()], $m);
            }
        }

        $data = $this->dataPersistor->get('nicolasbejean_categorywidget');

        if (!empty($data)) {
            $categoryWidget = $this->collection->getNewEmptyItem();
            $categoryWidget->setData($data);
            $this->loadedData[$categoryWidget->getId()] = $categoryWidget->getData();
            $this->dataPersistor->clear('nicolasbejean_categorywidget');
        }

        return $this->loadedData;
    }
}
