<?php
declare(strict_types=1);

namespace NicolasBejean\CategoryWidget\Model\Resolver\CategoryWidget;

use \NicolasBejean\CategoryWidget\Api\Data\CategoryWidgetInterface;

use \Magento\Framework\GraphQl\Query\Resolver\IdentityInterface;

/**
 * Class CategoryWidget
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Model\Resolver\CategoryWidget
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class Identity implements IdentityInterface
{
    /** @var string */
    private $cacheTag = \NicolasBejean\CategoryWidget\Model\CategoryWidget::CACHE_TAG;

    /**
     * Get Category Widget identities from resolved data
     *
     * @param array $resolvedData
     * @return string[]
     */
    public function getIdentities(array $resolvedData): array
    {
        $ids = [];
        $items = $resolvedData['items'] ?? [];
        foreach ($items as $item) {
            if (is_array($item) && !empty($item[CategoryWidgetInterface::ENTITY_ID])) {
                $ids[] = sprintf('%s_%s', $this->cacheTag, $item[CategoryWidgetInterface::ENTITY_ID]);
                $ids[] = sprintf('%s_%s', $this->cacheTag, $item[CategoryWidgetInterface::IDENTIFIER]);
            }
        }

        if (!empty($ids)) {
            array_unshift($ids, $this->cacheTag);
        }

        return $ids;
    }
}
