<?php
declare(strict_types=1);

namespace NicolasBejean\CategoryWidget\Model\Resolver\DataProvider;

use \NicolasBejean\CategoryWidget\Api\CategoryWidgetRepositoryInterface;
use \NicolasBejean\CategoryWidget\Api\Data\CategoryWidgetInterface;
use \NicolasBejean\CategoryWidget\Model\CategoryWidget as CategoryWidgetModel;

use \Magento\Widget\Model\Template\FilterEmulate;

use \Magento\Framework\Exception\NoSuchEntityException;

/**
 * Class CategoryWidget
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Model\Resolver\DataProvider
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class CategoryWidget
{
    /**
     * @var CategoryWidgetRepositoryInterface
     */
    private $categoryWidgetRepository;

    /**
     * @var FilterEmulate
     */
    private $widgetFilter;

    /**
     * @param CategoryWidgetRepositoryInterface $categoryWidgetRepository
     * @param FilterEmulate $widgetFilter
     */
    public function __construct(
        CategoryWidgetRepositoryInterface $categoryWidgetRepository,
        FilterEmulate $widgetFilter
    ) {
        $this->categoryWidgetRepository = $categoryWidgetRepository;
        $this->widgetFilter = $widgetFilter;
    }

    /**
     * Get Category Widget data
     *
     * @param string $categoryWidgetIdentifier
     * @return array
     * @throws NoSuchEntityException
     */
    public function getData(string $categoryWidgetIdentifier): array
    {
        /** @var CategoryWidgetModel $categoryWidget */
        $categoryWidget = $this->categoryWidgetRepository->getById($categoryWidgetIdentifier);

        if (false === $categoryWidget->isActive()) {
            throw new NoSuchEntityException(
                __('The Category Widget with the "%1" ID doesn\'t exist.', $categoryWidgetIdentifier)
            );
        }

        /* TODO : Faire un explode du content pour renvoyer chaque category widget*/
        $content = $categoryWidget->getContent();

        $categoryWidgetData = [
            CategoryWidgetInterface::IDENTIFIER => $categoryWidget->getIdentifier(),
            CategoryWidgetInterface::NAME => $categoryWidget->getName(),
            CategoryWidgetInterface::CONTENT => $content,
        ];
        return $categoryWidgetData;
    }
}
