<?php
namespace NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget;

use \Magento\Store\Model\Store;
use \NicolasBejean\CategoryWidget\Api\Data\CategoryWidgetInterface;
use \NicolasBejean\CategoryWidget\Model\CategoryWidget as CategoryWidgetModel;
use \NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget as CategoryWidgetResourceModel;
use \NicolasBejean\CategoryWidget\Model\ResourceModel\AbstractCollection;
use \Exception;

/**
 * Class Collection
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class Collection extends AbstractCollection
{
    /**
     * @var string
     */
    protected $_idFieldName = 'entity_id';

    /**
     * Event prefix
     *
     * @var string
     */
    protected $eventPrefix = 'categorywidget_collection';

    /**
     * Event object
     *
     * @var string
     */
    protected $eventObject = 'categorywidget_collection';

    /**
     * Perform operations after collection load
     *
     * @return AbstractCollection
     * @throws Exception
     */
    protected function _afterLoad()
    {
        $entityMetadata = $this->metadataPool->getMetadata(CategoryWidgetInterface::class);

        $this->performAfterLoad('nicolasbejean_categorywidget_store', $entityMetadata->getLinkField());

        return parent::_afterLoad();
    }

    /**
     * Define resource model
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_init(CategoryWidgetModel::class, CategoryWidgetResourceModel::class);
        $this->_map['fields']['store'] = 'store_table.store_id';
        $this->_map['fields']['entity_id'] = 'main_table.entity_id';
    }

    /**
     * Returns pairs entity_id - identifier
     *
     * @return array
     */
    public function toOptionArray()
    {
        return $this->_toOptionArray('entity_id', 'identifier');
    }

    /**
     * Add filter by store
     *
     * @param int|array|Store $store
     * @param bool $withAdmin
     * @return $this
     */
    public function addStoreFilter($store, $withAdmin = true)
    {
        $this->performAddStoreFilter($store, $withAdmin);

        return $this;
    }

    /**
     * Join store relation table if there is store filter
     *
     * @return void
     * @throws Exception
     */
    protected function _renderFiltersBefore()
    {
        $entityMetadata = $this->metadataPool->getMetadata(CategoryWidgetInterface::class);
        $this->joinStoreRelationTable('nicolasbejean_categorywidget_store', $entityMetadata->getLinkField());
    }
}
