<?php
namespace NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget\Grid;

use \Magento\Framework\Api\ExtensibleDataInterface;
use \Magento\Framework\Api\Search\SearchResultInterface;
use \Magento\Framework\Api\Search\AggregationInterface;
use \Magento\Framework\Api\SearchCriteriaInterface;
use \Magento\Framework\Data\Collection\Db\FetchStrategyInterface;
use \Magento\Framework\Data\Collection\EntityFactoryInterface;
use \Magento\Framework\DB\Adapter\AdapterInterface;
use \Magento\Framework\EntityManager\MetadataPool;
use \Magento\Framework\Event\ManagerInterface;
use \Magento\Framework\Model\ResourceModel\Db\AbstractDb;
use \Magento\Framework\View\Element\UiComponent\DataProvider\Document;
use \Magento\Store\Model\StoreManagerInterface;
use \NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget\Collection as CategoryWidgetCollection;
use \Psr\Log\LoggerInterface;

/**
 * Class Collection
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget\Grid
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class Collection extends CategoryWidgetCollection implements SearchResultInterface
{
    /**
     * @var AggregationInterface
     */
    protected $aggregations;

    /**
     * @param EntityFactoryInterface        $entityFactory
     * @param LoggerInterface               $logger
     * @param FetchStrategyInterface        $fetchStrategy
     * @param ManagerInterface              $eventManager
     * @param StoreManagerInterface         $storeManager
     * @param MetadataPool                  $metadataPool
     * @param string                        $mainTable
     * @param string                        $eventPrefix
     * @param string                        $eventObject
     * @param string                        $resourceModel
     * @param string                        $model
     * @param AdapterInterface              $connection
     * @param AbstractDb                    $resource
     *
     * @SuppressWarnings(PHPMD.ExcessiveParameterList)
     */
    public function __construct(
        EntityFactoryInterface              $entityFactory,
        LoggerInterface                     $logger,
        FetchStrategyInterface              $fetchStrategy,
        ManagerInterface                    $eventManager,
        StoreManagerInterface               $storeManager,
        MetadataPool                        $metadataPool,
        string                              $mainTable,
        string                              $eventPrefix,
        string                              $eventObject,
        string                              $resourceModel,
        string                              $model = Document::class,
        AdapterInterface                    $connection = null,
        AbstractDb                          $resource = null
    ) {
        $this->_eventPrefix                 = $eventPrefix;
        $this->_eventObject                 = $eventObject;

        parent::__construct(
            $entityFactory,
            $logger,
            $fetchStrategy,
            $eventManager,
            $storeManager,
            $metadataPool,
            $connection,
            $resource
        );

        $this->_init($model, $resourceModel);
        $this->setMainTable($mainTable);
    }

    /**
     * @return AggregationInterface
     */
    public function getAggregations()
    {
        return $this->aggregations;
    }

    /**
     * @param AggregationInterface $aggregations
     * @return $this
     */
    public function setAggregations($aggregations)
    {
        $this->aggregations = $aggregations;
        return $this;
    }

    /**
     * Get search criteria.
     *
     * @return SearchCriteriaInterface|null
     */
    public function getSearchCriteria()
    {
        return null;
    }

    /**
     * Set search criteria.
     *
     * @param SearchCriteriaInterface $searchCriteria
     * @return $this
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function setSearchCriteria(SearchCriteriaInterface $searchCriteria = null)
    {
        return $this;
    }

    /**
     * Get total count.
     *
     * @return int
     */
    public function getTotalCount()
    {
        return $this->getSize();
    }

    /**
     * Set total count.
     *
     * @param int $totalCount
     * @return $this
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function setTotalCount($totalCount)
    {
        return $this;
    }

    /**
     * Set items list.
     *
     * @param ExtensibleDataInterface[] $items
     * @return $this
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function setItems(array $items = null)
    {
        return $this;
    }
}
