<?php
namespace NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget\Relation\Store;

use \Magento\Framework\EntityManager\Operation\ExtensionInterface;
use \NicolasBejean\CategoryWidget\Api\Data\CategoryWidgetInterface;
use \NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget;
use \Magento\Framework\EntityManager\MetadataPool;
use \Exception;

/**
 * Class SaveHandler
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Model\ResourceModel\CategoryWidget\Relation\Store
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class SaveHandler implements ExtensionInterface
{
    /**
     * @var MetadataPool
     */
    protected $metadataPool;

    /**
     * @var CategoryWidget
     */
    protected $resourceCategoryWidget;

    /**
     * @param MetadataPool          $metadataPool
     * @param CategoryWidget           $resourceCategoryWidget
     */
    public function __construct(
        MetadataPool                $metadataPool,
        CategoryWidget                 $resourceCategoryWidget
    ) {
        $this->metadataPool         = $metadataPool;
        $this->resourceCategoryWidget  = $resourceCategoryWidget;
    }

    /**
     * @param object $entity
     * @param array $arguments
     * @return object
     * @throws Exception
     */
    public function execute($entity, $arguments = [])
    {
        $entityMetadata = $this->metadataPool->getMetadata(CategoryWidgetInterface::class);
        $linkField = $entityMetadata->getLinkField();

        $connection = $entityMetadata->getEntityConnection();

        $oldStores = $this->resourceCategoryWidget->lookupStoreIds((int)$entity->getId());
        $newStores = (array)$entity->getStores();

        $table = $this->resourceCategoryWidget->getTable('nicolasbejean_categorywidget_store');

        $delete = array_diff($oldStores, $newStores);
        if ($delete) {
            $where = [
                $linkField . ' = ?' => (int)$entity->getData($linkField),
                'store_id IN (?)' => $delete,
            ];
            $connection->delete($table, $where);
        }

        $insert = array_diff($newStores, $oldStores);
        if ($insert) {
            $data = [];
            foreach ($insert as $storeId) {
                $data[] = [
                    $linkField => (int)$entity->getData($linkField),
                    'store_id' => (int)$storeId,
                ];
            }
            $connection->insertMultiple($table, $data);
        }

        return $entity;
    }
}
