<?php
namespace NicolasBejean\CategoryWidget\Model\Template;

use \Magento\Framework\Filter\Template;
use \Magento\Framework\ObjectManagerInterface;
use \Exception;

/**
 * Class FilterProvider
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Model\Template
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class FilterProvider
{
    /**
     * @var ObjectManagerInterface
     */
    protected $objectManager;

    /**
     * @var string
     */
    /** TODO : A Delete ?  */
    protected $categoryWidgetFilter;

    /**
     * @var array
     */
    protected $instanceList;

    /**
     * @param ObjectManagerInterface $objectManager
     * @param string $categoryWidgetFilter
     */
    public function __construct(
        ObjectManagerInterface $objectManager,
        $categoryWidgetFilter = Filter::class
    ) {
        $this->objectManager = $objectManager;
        $this->categoryWidgetFilter = $categoryWidgetFilter;
    }

    /**
     * @param string $instanceName
     * @return Template
     * @throws Exception
     */
    protected function _getFilterInstance($instanceName)
    {
        if (!isset($this->instanceList[$instanceName])) {
            $instance = $this->objectManager->get($instanceName);

            if (!$instance instanceof Template) {
                throw new Exception('Template filter ' . $instanceName . ' does not implement required interface');
            }
            $this->instanceList[$instanceName] = $instance;
        }

        return $this->instanceList[$instanceName];
    }

    /**
     * @return Template
     * @throws Exception
     */
    public function getCategoryWidgetFilter()
    {
        return $this->_getFilterInstance($this->categoryWidgetFilter);
    }
}
