<?php
namespace NicolasBejean\CategoryWidget\Ui\Component\Listing\Column;

use \Magento\Framework\UrlInterface;
use \Magento\Framework\View\Element\UiComponent\ContextInterface;
use \Magento\Framework\View\Element\UiComponentFactory;
use \Magento\Ui\Component\Listing\Columns\Column;
use \Magento\Framework\App\ObjectManager;
use \Magento\Framework\Escaper;

/**
 * Class CategoryWidgetActions
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Ui\Component\Listing\Column
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class CategoryWidgetActions extends Column
{
    /**
     * Url path
     */
    const URL_PATH_EDIT = 'nicolasbejeancategorywidget/categorywidget/edit';
    const URL_PATH_DELETE = 'nicolasbejeancategorywidget/categorywidget/delete';

    /**
     * @var UrlInterface
     */
    protected $urlBuilder;

    /**
     * @var Escaper
     */
    private $escaper;

    /**
     * Constructor
     *
     * @param ContextInterface      $context
     * @param UiComponentFactory    $uiComponentFactory
     * @param UrlInterface          $urlBuilder
     * @param array                 $components
     * @param array                 $data
     */
    public function __construct(
        ContextInterface            $context,
        UiComponentFactory          $uiComponentFactory,
        UrlInterface                $urlBuilder,
        array                       $components = [],
        array                       $data = []
    ) {
        $this->urlBuilder           = $urlBuilder;

        parent::__construct($context, $uiComponentFactory, $components, $data);
    }

    /**
     * Prepare Data Source
     *
     * @param array $dataSource
     * @return array
     */
    public function prepareDataSource(array $dataSource)
    {
        if (isset($dataSource['data']['items'])) {
            foreach ($dataSource['data']['items'] as & $item) {
                if (isset($item['entity_id'])) {
                    $identifier = $this->getEscaperHtml($item['identifier']);
                    $item[$this->getData('name')] = [
                        'edit' => [
                            'href' => $this->urlBuilder->getUrl(
                                static::URL_PATH_EDIT,
                                [
                                    'entity_id' => $item['entity_id']
                                ]
                            ),
                            'label' => __('Edit')
                        ],
                        'delete' => [
                            'href' => $this->urlBuilder->getUrl(
                                static::URL_PATH_DELETE,
                                [
                                    'entity_id' => $item['entity_id']
                                ]
                            ),
                            'label' => __('Delete'),
                            'confirm' => [
                                'identifier' => __('Delete %1', $identifier),
                                'message' => __('Are you sure you want to delete a %1 record?', $identifier)
                            ],
                            'post' => true
                        ]
                    ];
                }
            }
        }

        return $dataSource;
    }

    /**
     * @param string|array $data
     * @return array|string
     */
    private function getEscaperHtml($data)
    {
        if (!$this->escaper) {
            $this->escaper = ObjectManager::getInstance()->get(Escaper::class);
            return $this->escaper->escapeHtml($data);
        }
    }
}
